
![](https://www.phonexia.com/wp-content/uploads/phonexia-logo-transparent-500px.png)

# Phonexia age estimation client

This module contains client for communication with [age estimation microservice](https://hub.docker.com/repository/docker/phonexia/age-estimation/general) developed by [Phonexia](https://phonexia.com).

To use this client you will first need a running instance of any *Phonexia age estimation microservice*. If you don't yet have any running instance, don't hesitate to [contact our sales department](mailto:info@phonexia.com).

You can learn more about the age estimation technology [here](https://docs.phonexia.com/products/speech-platform-4/technologies/age-estimation/).

On [this page](https://docs.phonexia.com/products/speech-platform-4/grpc/api/phonexia/grpc/technologies/age_estimation/v1/age_estimation.proto#ageestimation), you will find a *gRPC API* reference for *age estimation microservice*.